-- ============================================================
--
--   The game's main file
--   Just calls all the other modules
--
-- ============================================================


-- ============================================================
--   Basic initializations
-- ============================================================
--
-- First statement executed : print an empty line on console,
-- so subsequent print() results will appear correctly
print("")

-- Hide mouse
love.mouse.setVisible(false)

-- Init random numbers generator
math.randomseed(os.time())

love.load        = require("src/callbacks/load")
--
-- ============================================================


-- ============================================================
--   Declare debugging facility as a globaal variable
-- ============================================================
--
dbg = require("src/debug/debug")
--
-- ============================================================


-- ============================================================
--   A set of global variables and functions
--   Warning : don't have everything ending up there !
-- ============================================================
--
require("src/globals/globalVariables")
require("src/globals/globalFunctions")
--
-- ============================================================


-- ============================================================
--   Library objects
--   Ideal call is Lua 5.1+ style :
--     libName = require 'lib.name'
--   Some libraries can only be called by an old-fashioned
--   plain require statement
-- ============================================================
--
Layout = require 'lib.luigi.layout'		-- Luigi GUI
SLAXML = require 'lib.slaxml.slaxdom'	-- XML Parser
require("lib/MiddleClass/MiddleClass")		-- OOP framework
require("lib/MiddleClass/StatefulObject")	-- FSM objects
--
-- ============================================================


-- ============================================================
--   Classes definitions
-- ============================================================
--
-- Contains the game states and gameplay logic
clsGame        = require("src/clsGame/clsGame")
require("src/clsGame/stateMenu/stateMenu")
require("src/clsGame/stateOptions/stateOptions")
require("src/clsGame/stateCredits/stateCredits")
require("src/clsGame/statePlay/statePlay")
require("src/clsGame/stateGameOver/stateGameOver")

-- Holds main actor logics : position, speed and acceleration
clsActor       = require("src/clsActor/clsActor")

-- An animation is just a specialized actor with a sprite
-- and timed display
clsAnimation   = require("src/clsActor/clsAnimation/clsAnimation")

-- A space object's sprite is drawn based on the actor's orientation
clsSpaceObject = require("src/clsActor/clsSpaceObject/clsSpaceObject")

-- Asteroids, Ships and Projectiles are different kinds of space objects
clsAsteroid   = require("src/clsActor/clsSpaceObject/clsAsteroid/clsAsteroid")
clsShip       = require("src/clsActor/clsSpaceObject/clsShip/clsShip")
clsProjectile = require("src/clsActor/clsSpaceObject/clsProjectile/clsProjectile")
clsBeam       = require("src/clsActor/clsSpaceObject/clsBeam/clsBeam")
--
-- ============================================================


-- ============================================================
--   Implement LÖVE callbacks
-- ============================================================
--
love.update      = require("src/callbacks/update")
love.draw        = require("src/callbacks/draw")
love.keypressed  = require("src/callbacks/keypressed")
love.keyreleased = require("src/callbacks/keyreleased")
--
-- ============================================================
