-- ============================================================
--
--   Actor Class
--     Contains position (x, y, rot) and speed (sx, sy, srot)
--     Base update(dt) function
--
-- ============================================================


-- ============================================================
--   Class definition
-- ============================================================
--
local clsActor = class("clsActor")
--
-- ============================================================


-- ============================================================
--   initialize : called at new()
-- ============================================================
--
function clsActor:initialize(
	objGame,
	numX, numY, numHeading,
	numSpeedX, numSpeedY, numRotationSpeed
)
	-- Check parameters and enforce default values : sprite image is mandatory
	if objGame == nil then
		return
	end
	if numX == nil then
		numX = objGame.options.screenWidth/2
	end
	if numY == nil then
		numY = objGame.options.screenHeight/2
	end
	if numHeading == nil then
		numHeading = 0
	end
	if numSpeedX == nil then
		numSpeedX = 0
	end
	if numSpeedY == nil then
		numSpeedY = 0
	end
	if numRotationSpeed == nil then
		numRotationSpeed = 0
	end

	-- State properties
	self.position       = {x = numX     , y = numY     , heading  = numHeading      }
	self.speed          = {x = numSpeedX, y = numSpeedY, rotation = numRotationSpeed}

	-- Flags
	self.isAlive     = true  -- Object is alive, if false, must be destroyed
end
--
-- ============================================================


-- ============================================================
--   update : called by the game's global love.update()
-- ============================================================
--
function clsActor:update(dt)
	-- Update position in pixel from speed
	self.position.x = self.position.x + dt*self.speed.x
	self.position.y = self.position.y + dt*self.speed.y

	-- Update heading in radians from rotation speed
	self.position.heading = (self.position.heading + dt*self.speed.rotation) % math.rad(360)
end
--
-- ============================================================


-- ============================================================
--   Return the class object
-- ============================================================
--
return clsActor
--
-- ============================================================
