-- ============================================================
--
--   Asteroid Object Class
--
-- ============================================================


-- ============================================================
--   Class definition
-- ============================================================
--
local clsAsteroid = class("clsAsteroid", clsSpaceObject)
--
-- ============================================================


-- ============================================================
--   initialize : called at new()
-- ============================================================
--
function clsAsteroid:initialize(
	objGame,
	sprSprite, numSize,
	numX, numY, numHeading,
	numSpeedX, numSpeedY, numRotationSpeed
)
	-- Check parameters and enforce default values
	if objGame == nil then
		return
	end
	if sprSprite == nil then
		return nil
	end
	if numSize == nil then
		numSize = 2
	end
	if numX == nil then
		numX = 0
	end
	if numY == nil then
		numY = 0
	end
	if numHeading == nil then
		numHeading = 0
	end
	if numSpeedX == nil then
		numSpeedX = 0
	end
	if numSpeedY == nil then
		numSpeedY = 0
	end
	if numRotationSpeed == nil then
		numRotationSpeed = 90
	end

	-- Call parent class
	clsSpaceObject.initialize(self, objGame, sprSprite, 1, 1, numSize/2, numX, numY, numHeading, numSpeedX, numSpeedY, numRotationSpeed)

	-- Capacity properties : rotation is constant
	self.size = numSize
	self.capabilities = {
		rotation     =  numRotationSpeed -- Deg/sec
	}
	self.remainingMass = numSize^3

	-- Flags
	self.isDanger   = false -- Asteroid is dangerous for the player, but not yet colliding
	self.canBeMined = false -- Asteroid is near enough to the ship to be mined
end
--
-- ============================================================


-- ============================================================
--   update : called by the game's global love.update()
-- ============================================================
--
function clsAsteroid:update(dt)
	-- First call parent class
	clsSpaceObject.update(self, dt)
end
--
-- ============================================================


-- ============================================================
--   draw : called by the game's global love.draw()
-- ============================================================
--
function clsAsteroid:draw()
	-- Draw the base object
	clsSpaceObject.draw(self)

	-- Always draw the speed vector
	clsSpaceObject.drawSpeedVector(self)
end
--
-- ============================================================


-- ============================================================
--   Return the class object
-- ============================================================
--
return clsAsteroid
--
-- ============================================================
