-- ============================================================
--
--   Beam Object Class
--
-- ============================================================


-- ============================================================
--   Class definition
-- ============================================================
--
local clsBeam = class("clsBeam", clsSpaceObject)
--
-- ============================================================


-- ============================================================
--   initialize : called at new()
-- ============================================================
--
function clsBeam:initialize(
	objGame,
	sprSprite,
	objShip,
	objAsteroid
)
	-- Check parameters and enforce default values
	if objGame == nil then
		return
	end
	if sprSprite == nil then
		return nil
	end
	if objShip == nil then
		return nil
	end
	if objAsteroid == nil then
		return nil
	end

	-- Local variables
	local numX       = objShip.position.x + objAsteroid.position.x
	local numY       = objShip.position.y + objAsteroid.position.y

	-- Call parent class
	clsSpaceObject.initialize(self, objGame, sprSprite, 1, 1, 1, numX, numY)

	-- Complete properties
	self.scale = {
		height = 1,
		width =  1
	}
	self.objShip     = objShip
	self.objAsteroid = objAsteroid

	-- Derive position from reference objects
	self.position.x       = (objShip.position.x + objAsteroid.position.x)/2
	self.position.y       = (objShip.position.y + objAsteroid.position.y)/2

	-- Derive heading and width from reference objects
	local deltaX          = self.objShip.position.x - self.objAsteroid.position.x
	local deltaY          = self.objShip.position.y - self.objAsteroid.position.y
	self.position.heading = math.atan2(deltaY, deltaX)
	self.scale.width      = math.sqrt(deltaX^2 + deltaY^2)/self.sprite.width
end
--
-- ============================================================


-- ============================================================
--   draw : called by the game's global love.draw()
-- ============================================================
--
function clsBeam:draw()
	love.graphics.draw(
		self.sprite.image,
		self.sprite.frame[0],
		self.position.x,
		self.position.y,
		self.position.heading,
		self.scale.width,
		self.scale.height,
		self.sprite.width/2,
		self.sprite.height/2
	)
end
--
-- ============================================================


	-- ============================================================
--   Return the class object
-- ============================================================
--
return clsBeam
--
-- ============================================================
