-- ============================================================
--
--   Projectile Object Class
--
-- ============================================================


-- ============================================================
--   Class definition
-- ============================================================
--
local clsProjectile = class("clsProjectile", clsSpaceObject)
--
-- ============================================================


-- ============================================================
--   initialize : called at new()
-- ============================================================
--
function clsProjectile:initialize(
	objGame,
	sprSprite, numSize,
	objShip,
	numDeltaSpeed
)
	-- Check parameters and enforce default values
	if objGame == nil then
		return
	end
	if sprSprite == nil then
		return nil
	end
	if numSize == nil then
		numSize = 2
	end
	if objShip == nil then
		return
	end
	if numDeltaSpeed == nil then
		numDeltaSpeed= 200
	end

	-- Local variables
	local numNX      = 6
	local numNY      = 6
	local numScale   = 1
	local numX       = objShip.position.x
	local numY       = objShip.position.y
	local numSpeedX  = objShip.speed.x + numDeltaSpeed * math.cos(objShip.position.heading)
	local numSpeedY  = objShip.speed.y + numDeltaSpeed * math.sin(objShip.position.heading)
	local numHeading = math.atan2(numSpeedY, numSpeedX)

	-- Call parent class
	clsSpaceObject.initialize(self, objGame, sprSprite, numNX, numNY, numSize, numX, numY, numHeading, numSpeedX, numSpeedY)

	-- Sprite size
	self.size = numSize

	-- Flags
	self.isNew = 0          -- Projectile can hit asteroids as soon as created
end
--
-- ============================================================


-- ============================================================
--   update : called by the game's global love.update()
-- ============================================================
--
function clsProjectile:update(dt)
	-- First call parent class
	clsSpaceObject.update(self, dt)
end
--
-- ============================================================


	-- ============================================================
--   Return the class object
-- ============================================================
--
return clsProjectile
--
-- ============================================================
