-- ============================================================
--
--   Load ships definitions
--
-- ============================================================


-- ============================================================
-- Load ships definitions
-- ============================================================
--
local function loadShipsDefinitions(self)
	-- Init available ships table field, and make a local variable point to it
	self.tabShipData = {}
	local tabShipData = self.tabShipData

	-- Debug
	print("Loading ships definitions")

		-- Get ship definition files from data folder
	local tabShipFilesList = love.filesystem.getDirectoryItems( strShipDataDir )
	for k, file in ipairs(tabShipFilesList) do
		if string.sub(file,-4)==".xml" then
			--Instantiates the XML parser
			local strXML = love.filesystem.read( strShipDataDir .. "/" .. file )
			local doc = SLAXML:dom(strXML)
			local docOutput = convertSLAXMLtoReadable(doc)

			-- Get the ship's name
			local strShipName = docOutput.ship[1].name

			local strShipDescription = (docOutput.ship[1].description[1].value):gsub("\r","")
			-- print ( strShipName, "\r\n", strShipDescription )

			-- Get sprite dimensions : if 1x1, do not load
			local numNX = tonumber(docOutput.ship[1].GFX[1].sx)
			local numNY = tonumber(docOutput.ship[1].GFX[1].sy)
			if numNX==1 or numNY==1 then
				print ( "\t>>> ERROR on Ship \"" .. strShipName .. "\" : 1x1 sprite" )
				print ( "\t>>> SHIP LOADING ABORTED" )
			else
				-- Load ship
				local strBaseName = docOutput.ship[1].base_type[1].value
				local strGFXname  = docOutput.ship[1].GFX[1].value
				local strDirName  = ""
				if (strShipName == strBaseName) then
					strDirName  = string.lower(strGFXname):gsub("[' ]", "")
				else
					strDirName  = string.lower(strBaseName):gsub("[' ]", "")
				end
				local strFileName = strShipImagesDir .. "/" .. strDirName .. "/" .. strGFXname .. ".png"

				-- Check if image file exists
				if love.filesystem.isFile(strFileName) then
					tabShipData[#tabShipData+1] = {
						name        = strShipName,
						description = strShipDescription,
						fileName    = strFileName,
						sprite      = love.graphics.newImage(strFileName),
						nX          = numNX,
						nY          = numNY,
						stats       = {
							acceleration = docOutput.ship[1].AM_stats[1].Acceleration[1].value,
							deceleration = docOutput.ship[1].AM_stats[1].Deceleration[1].value,
							turnRate     = docOutput.ship[1].AM_stats[1].TurnRate[1].value,
							miningBeam   = docOutput.ship[1].AM_stats[1].MiningBeam[1].value,
							cargoHold    = docOutput.ship[1].AM_stats[1].CargoHold[1].value,
							shield       = docOutput.ship[1].AM_stats[1].Shield[1].value,
							laser        = docOutput.ship[1].AM_stats[1].Laser[1].value
						}
					}
				else
					print ( "\t>>> ERROR  on Ship \"" .. strShipName .. "\" : image file \"" .. strFileName .. "\" does not exist" )
					print ( "\t>>> SHIP LOADING ABORTED" )
				end
			end
		end
		for k,v in pairs(tabShipData[#tabShipData].stats) do
			print ( k, v )
		end
	end
	print ( "Successfully loaded " .. #tabShipData .. " ships\r\n" )
end
--
-- ============================================================


-- ============================================================
--   Return the function
-- ============================================================
--
return loadShipsDefinitions
--
-- ============================================================
