-- ============================================================
--
--   The game's "GameOver" state
--
-- ============================================================


-- ============================================================
-- Define the state and its variables
--   Here will be the actual gameflow
-- ============================================================
--
-- Create the state
local stateGameOver = clsGame:addState("GameOver")

-- Current player ship
local objShip = nil
currentShip = clsGame.currentShip

-- Set the layout and style for displaying the menu
local layoutGameOver = Layout( require("src/clsGame/stateGameOver/layoutGameOver") )
layoutGameOver:setStyle( require("src/gui/styleDefault") )

-- Set an action for each Menu button
layoutGameOver.btnExit:onPress(
	function()
		objGame:gotoState("Menu")
	end
)
--
-- ============================================================


-- ============================================================
-- Called when entering the state
-- ============================================================
--
function stateGameOver:enterState()
	-- Temporary local variables
	local strMessage = ""
	local strHeader  = ""

	-- Make locals from globals
	local gameStatus = clsGame.status
	local strNewLine = "\n"
 
	if gameStatus.exitHit then
		strHeader  = "Game Over"
		strMessage =                               ("You were hit by an asteroid after %5.2f s"):format(gameStatus.elapsedTime)
		strMessage = strMessage .. strNewLine ..   ("Run results : %5.2f units of ore mined, %i asteroids destroyed"):format(gameStatus.oreMined, gameStatus.asteroidsDestroyed)
		strMessage = strMessage .. strNewLine ..   ("Run Score : %i"):format(gameStatus.runScore)
		if gameStatus.gameScore==gameStatus.runScore then
			strMessage = strMessage ..  ", no previous score"
		else
			strMessage = strMessage .. (", previous Score : %i"):format(gameStatus.gameScore-gameStatus.runScore)
		end
		strMessage = strMessage .. strNewLine 
		strMessage = strMessage .. strNewLine ..   ("Final score : %i"):format(gameStatus.gameScore)
	else
		strHeader  = "Safe Exit"
		strMessage =                               ("You safely exited the mining zone after %5.2f s"):format(gameStatus.elapsedTime)
		strMessage = strMessage .. strNewLine ..   ("Run results : %5.2f units of ore mined, %i asteroids destroyed"):format(gameStatus.oreMined, gameStatus.asteroidsDestroyed)
		strMessage = strMessage .. strNewLine ..   ("Run Score : %i"):format(gameStatus.runScore)
		if gameStatus.gameScore==gameStatus.runScore then
			strMessage = strMessage ..  ", no previous score"
		else
			strMessage = strMessage .. (", previous Score : %i"):format(gameStatus.gameScore-gameStatus.runScore)
		end
		strMessage = strMessage .. strNewLine
		strMessage = strMessage .. strNewLine ..   ("Total score this far : %i"):format(gameStatus.gameScore)
		strMessage = strMessage .. strNewLine ..    "You can add to this score by trying further mining runs..."
	end
 
	love.mouse.setVisible(true)
	layoutGameOver.dialogHeader.text = strHeader
	layoutGameOver.txtText.text      = strMessage
	layoutGameOver:show()
end
--
-- ============================================================


-- ============================================================
-- Called when exiting the state to enter another state
-- ============================================================
--
function stateGameOver:exitState()
	love.mouse.setVisible(false)
	layoutGameOver:hide()
end
--
-- ============================================================
