-- ============================================================
--
--   The game's "Menu" state
--
-- ============================================================


-- ============================================================
-- Define the state and its variables
--   Here will be the actual gameflow
-- ============================================================
--
-- Create the state
local stateOptions = clsGame:addState("Options")

-- Set the layout and style for displaying the menu
local layoutOptions = Layout( require("src/clsGame/stateOptions/layoutOptions") )
layoutOptions:setStyle( require("src/gui/styleDefault") )

-- Set an action for each Menu button
layoutOptions.btnCancel:onPress(
	function()
		objGame:gotoState("Menu")
	end
)
layoutOptions.btnApply:onPress(
	function()
		if layoutOptions.chkFullscreen.value then
			-- Just enter fullscreen mode, let LÖVE find the best resolution
			love.window.setFullscreen( true )
		else
			-- For now, use hard-coded globals, should be derived from love.conf values
			local tabLoveConf = {}
			tabLoveConf.window = {}
			tabLoveConf.modules = {}
			love.conf(tabLoveConf)
			love.window.setMode(tabLoveConf.window.width, tabLoveConf.window.height, {fullscreen=false})
		end

		objGame.options.screenWidth, objGame.options.screenHeight = love.graphics.getDimensions()

		-- Display menu
		objGame:gotoState("Menu")
	end
)
--
-- ============================================================


-- ============================================================
-- Called when entering the state
-- ============================================================
--
function stateOptions:enterState()
	layoutOptions.chkFullscreen.value = love.window.getFullscreen()
	-- Show panel
	love.mouse.setVisible(true)
	layoutOptions:show()
end
--
-- ============================================================


-- ============================================================
-- Called when exiting the state to enter another state
-- ============================================================
--
function stateOptions:exitState()
	love.mouse.setVisible(false)
	layoutOptions:hide()
end
--
-- ============================================================
