-- ============================================================
--
--   Functions declared as global
--   Warning : don't have everything ending up there !
--
-- ============================================================


-- ============================================================
--   Convert SLAXML document into a more readable form
-- ============================================================
--
function convertSLAXMLtoReadable(docInput, parent, index)
	-- Build empty output table
	local docOutput = {}

	-- Store direct properties
	docOutput.type = docInput.type
	docOutput.name = docInput.name
	if docInput.kids[1]~= nil then
		docOutput.value = docInput.kids[1].value
	end

	if docOutput.type == "document" then
		-- Build path, no parent
		local strRootName = docInput.root.name
		docOutput.path = "root"
	
		-- Recursive call
		docOutput[strRootName] = {}
		docOutput[strRootName][1] = convertSLAXMLtoReadable(docInput.root, docOutput, 1)
		return docOutput
	end

	if docOutput.type == "element" then
		-- Build path and parent
		docOutput.parent = parent
		docOutput.path = ("%s.%s[%i]"):format(parent.path, docInput.name, index)
	
		-- Get attributes
		for k,v in pairs(docInput.attr) do
			if type(k)~="string" then
				docOutput[v.name] = v.value
			end
		end

		-- Get child elements
		for k,v in pairs(docInput.el) do
			if docOutput[v.name]==nil then
				docOutput[v.name] = {}
				docOutput[v.name][1] = convertSLAXMLtoReadable(v, docOutput, 1)
			else
				docOutput[v.name][#docOutput[v.name]+1] = convertSLAXMLtoReadable(v, docOutput, #docOutput[v.name]+1)
			end
		end
		
		-- Return the element
		return docOutput
	end
end
--
-- ============================================================
